Non-parametric tests for Multiple Comparison — STAC 0.7 documentation

### Navigation

- index
- STAC 0.7 documentation »

# Non-parametric tests for Multiple Comparison

Ranking tests

`friedman_test`(*args) | Performs a Friedman ranking test.
`friedman_aligned_ranks_test`(*args) | Performs a Friedman aligned ranks ranking test.
`quade_test`(*args) | Performs a Quade ranking test.

Post-hoc 1 vs all tests

`bonferroni_test` |
`holm_test`(ranks[, control]) | Performs a Holm post-hoc test using the pivot quantities obtained by a ranking test.
`finner_test`(ranks[, control]) | Performs a Finner post-hoc test using the pivot quantities obtained by a ranking test.
`hochberg_test`(ranks[, control]) | Performs a Hochberg post-hoc test using the pivot quantities obtained by a ranking test.
`li_test`(ranks[, control]) | Performs a Li post-hoc test using the pivot quantities obtained by a ranking test.

Post-hoc all vs all tests

`nemenyi_multitest`(ranks) | Performs a Nemenyi post-hoc test using the pivot quantities obtained by a ranking test.
`holm_multitest`(ranks) | Performs a Holm post-hoc test using the pivot quantities obtained by a ranking test.
`finner_multitest`(ranks) | Performs a Finner post-hoc test using the pivot quantities obtained by a ranking test.
`hochberg_multitest`(ranks) | Performs a Hochberg post-hoc test using the pivot quantities obtained by a ranking test.
`shaffer_multitest`(ranks) | Performs a Shaffer post-hoc test using the pivot quantities obtained by a ranking test.

### Navigation

- index
- STAC 0.7 documentation »